all messages for Guix-related lists mirrored at yhetil.org
 help / color / mirror / code / Atom feed
* [PATCH 0/5] gnu/packages/aux-files
@ 2017-02-18  9:21 Alex Kost
  2017-02-18  9:21 ` [PATCH 1/5] packages: Add 'search-auxiliary-file' Alex Kost
                   ` (5 more replies)
  0 siblings, 6 replies; 10+ messages in thread
From: Alex Kost @ 2017-02-18  9:21 UTC (permalink / raw)
  To: guix-devel

Hello, as discussed at

  http://lists.gnu.org/archive/html/guix-devel/2016-12/msg01174.html

this patchset moves linux-libre .conf files and "guix-emacs.el" (needed
for Emacs) to "gnu/packages/aux-files", also it modifies "guix-emacs.el"
a bit.  These patches shouldn't change anything in a user experience.

The .conf files will be called like this:

  gnu/packages/aux-files/linux-libre/4.9-i686.conf

or is it better to name them like this:

  gnu/packages/aux-files/linux-libre/linux-libre-4.9-i686.conf   or
  gnu/packages/aux-files/linux-libre-4.9-i686.conf

or something else?

IIUC Ludovic is AFK now, so I would like to push these patches in a week
or so, if there will be no comments.

[PATCH 1/5] packages: Add 'search-auxiliary-file'.
[PATCH 2/5] gnu: linux: Move configuration files to "aux-files".
[PATCH 3/5] gnu: emacs: Move "guix-emacs.el" to "aux-files".
[PATCH 4/5] gnu: emacs: Simplify "guix-emacs.el".
[PATCH 5/5] .gitignore: Remove stale entries.

11 files changed, 31 insertions(+), 49 deletions(-)
.gitignore                                         |  5 -----
Makefile.am                                        | 21 ++++++++++---------
.../packages/aux-files/emacs}/guix-emacs.el        | 21 +++++--------------
.../linux-libre/4.1-i686.conf}                     |  0 
.../linux-libre/4.1-x86_64.conf}                   |  0 
.../linux-libre/4.4-i686.conf}                     |  0 
.../linux-libre/4.4-x86_64.conf}                   |  0 
.../linux-libre/4.9-i686.conf}                     |  0 
.../linux-libre/4.9-x86_64.conf}                   |  0 
gnu/packages/emacs.scm                             | 24 ++++++++++------------
gnu/packages/linux.scm                             |  9 ++++----

^ permalink raw reply	[flat|nested] 10+ messages in thread

* [PATCH 1/5] packages: Add 'search-auxiliary-file'.
  2017-02-18  9:21 [PATCH 0/5] gnu/packages/aux-files Alex Kost
@ 2017-02-18  9:21 ` Alex Kost
  2017-02-18  9:21 ` [PATCH 2/5] gnu: linux: Move configuration files to "aux-files" Alex Kost
                   ` (4 subsequent siblings)
  5 siblings, 0 replies; 10+ messages in thread
From: Alex Kost @ 2017-02-18  9:21 UTC (permalink / raw)
  To: guix-devel

Suggested-by: Ludovic Courtès <ludo@gnu.org> at
<http://lists.gnu.org/archive/html/guix-devel/2016-12/msg01174.html>.

* gnu/packages.scm (%auxiliary-files-path): New variable.
(search-auxiliary-file): New procedure.
---
 gnu/packages.scm | 24 ++++++++++++++++++------
 1 file changed, 18 insertions(+), 6 deletions(-)

-- 
2.10.2

^ permalink raw reply related	[flat|nested] 10+ messages in thread

* [PATCH 2/5] gnu: linux: Move configuration files to "aux-files".
  2017-02-18  9:21 [PATCH 0/5] gnu/packages/aux-files Alex Kost
  2017-02-18  9:21 ` [PATCH 1/5] packages: Add 'search-auxiliary-file' Alex Kost
@ 2017-02-18  9:21 ` Alex Kost
  2017-02-18  9:21 ` [PATCH 3/5] gnu: emacs: Move "guix-emacs.el" " Alex Kost
                   ` (3 subsequent siblings)
  5 siblings, 0 replies; 10+ messages in thread
From: Alex Kost @ 2017-02-18  9:21 UTC (permalink / raw)
  To: guix-devel

* gnu/packages/linux-libre-4.1-i686.conf: Rename to...
* gnu/packages/aux-files/linux-libre/4.1-i686.conf: ... this.
* gnu/packages/linux-libre-4.1-x86_64.conf: Rename to...
* gnu/packages/aux-files/linux-libre/4.1-x86_64.conf: ... this.
* gnu/packages/linux-libre-4.4-i686.conf: Rename to...
* gnu/packages/aux-files/linux-libre/4.4-i686.conf: ... this.
* gnu/packages/linux-libre-4.4-x86_64.conf: Rename to...
* gnu/packages/aux-files/linux-libre/4.4-x86_64.conf: ... this.
* gnu/packages/linux-libre-4.9-i686.conf: Rename to...
* gnu/packages/aux-files/linux-libre/4.9-i686.conf: ... this.
* gnu/packages/linux-libre-4.9-x86_64.conf: Rename to...
* gnu/packages/aux-files/linux-libre/4.9-x86_64.conf: ... this.
* gnu/packages/linux.scm (kernel-config): Use 'search-auxiliary-file' to
find configuration files.
* Makefile.am (KCONFIGS): Rename to...
(AUX_FILES): ... this.  Adjust accordingly.
---
 Makefile.am                                          | 20 ++++++++++----------
 .../linux-libre/4.1-i686.conf}                       |  0
 .../linux-libre/4.1-x86_64.conf}                     |  0
 .../linux-libre/4.4-i686.conf}                       |  0
 .../linux-libre/4.4-x86_64.conf}                     |  0
 .../linux-libre/4.9-i686.conf}                       |  0
 .../linux-libre/4.9-x86_64.conf}                     |  0
 gnu/packages/linux.scm                               |  9 ++++-----
 8 files changed, 14 insertions(+), 15 deletions(-)
 rename gnu/packages/{linux-libre-4.1-i686.conf => aux-files/linux-libre/4.1-i686.conf} (100%)
 rename gnu/packages/{linux-libre-4.1-x86_64.conf => aux-files/linux-libre/4.1-x86_64.conf} (100%)
 rename gnu/packages/{linux-libre-4.4-i686.conf => aux-files/linux-libre/4.4-i686.conf} (100%)
 rename gnu/packages/{linux-libre-4.4-x86_64.conf => aux-files/linux-libre/4.4-x86_64.conf} (100%)
 rename gnu/packages/{linux-libre-4.9-i686.conf => aux-files/linux-libre/4.9-i686.conf} (100%)
 rename gnu/packages/{linux-libre-4.9-x86_64.conf => aux-files/linux-libre/4.9-x86_64.conf} (100%)

diff --git a/Makefile.am b/Makefile.am
index 8fe22d4..1e26da8 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -1,7 +1,7 @@
 # GNU Guix --- Functional package management for GNU
 # Copyright © 2012, 2013, 2014, 2015, 2016, 2017 Ludovic Courtès <ludo@gnu.org>
 # Copyright © 2013 Andreas Enge <andreas@enge.fr>
-# Copyright © 2015 Alex Kost <alezost@gmail.com>
+# Copyright © 2015, 2017 Alex Kost <alezost@gmail.com>
 # Copyright © 2016 Mathieu Lirzin <mthl@gnu.org>
 # Copyright © 2016 Mark H Weaver <mhw@netris.org>
 #
@@ -196,14 +196,14 @@ endif BUILD_DAEMON_OFFLOAD
 # Internal modules with test suite support.
 dist_noinst_DATA = guix/tests.scm guix/tests/http.scm
 
-# Linux-Libre configurations.
-KCONFIGS =					\
-  gnu/packages/linux-libre-4.9-i686.conf	\
-  gnu/packages/linux-libre-4.9-x86_64.conf	\
-  gnu/packages/linux-libre-4.4-i686.conf	\
-  gnu/packages/linux-libre-4.4-x86_64.conf	\
-  gnu/packages/linux-libre-4.1-i686.conf	\
-  gnu/packages/linux-libre-4.1-x86_64.conf
+# Auxiliary files for packages.
+AUX_FILES =						\
+  gnu/packages/aux-files/linux-libre/4.9-i686.conf	\
+  gnu/packages/aux-files/linux-libre/4.9-x86_64.conf	\
+  gnu/packages/aux-files/linux-libre/4.4-i686.conf	\
+  gnu/packages/aux-files/linux-libre/4.4-x86_64.conf	\
+  gnu/packages/aux-files/linux-libre/4.1-i686.conf	\
+  gnu/packages/aux-files/linux-libre/4.1-x86_64.conf
 
 # Templates, examples.
 EXAMPLES =					\
@@ -214,7 +214,7 @@ EXAMPLES =					\
 GOBJECTS = $(MODULES:%.scm=%.go) guix/config.go $(dist_noinst_DATA:%.scm=%.go)
 
 nobase_dist_guilemodule_DATA =                  \
-  $(MODULES) $(KCONFIGS) $(EXAMPLES)            \
+  $(MODULES) $(AUX_FILES) $(EXAMPLES)            \
   $(MISC_DISTRO_FILES)
 nobase_nodist_guilemodule_DATA = $(GOBJECTS) guix/config.scm
 
diff --git a/gnu/packages/linux-libre-4.1-i686.conf b/gnu/packages/aux-files/linux-libre/4.1-i686.conf
similarity index 100%
rename from gnu/packages/linux-libre-4.1-i686.conf
rename to gnu/packages/aux-files/linux-libre/4.1-i686.conf
diff --git a/gnu/packages/linux-libre-4.1-x86_64.conf b/gnu/packages/aux-files/linux-libre/4.1-x86_64.conf
similarity index 100%
rename from gnu/packages/linux-libre-4.1-x86_64.conf
rename to gnu/packages/aux-files/linux-libre/4.1-x86_64.conf
diff --git a/gnu/packages/linux-libre-4.4-i686.conf b/gnu/packages/aux-files/linux-libre/4.4-i686.conf
similarity index 100%
rename from gnu/packages/linux-libre-4.4-i686.conf
rename to gnu/packages/aux-files/linux-libre/4.4-i686.conf
diff --git a/gnu/packages/linux-libre-4.4-x86_64.conf b/gnu/packages/aux-files/linux-libre/4.4-x86_64.conf
similarity index 100%
rename from gnu/packages/linux-libre-4.4-x86_64.conf
rename to gnu/packages/aux-files/linux-libre/4.4-x86_64.conf
diff --git a/gnu/packages/linux-libre-4.9-i686.conf b/gnu/packages/aux-files/linux-libre/4.9-i686.conf
similarity index 100%
rename from gnu/packages/linux-libre-4.9-i686.conf
rename to gnu/packages/aux-files/linux-libre/4.9-i686.conf
diff --git a/gnu/packages/linux-libre-4.9-x86_64.conf b/gnu/packages/aux-files/linux-libre/4.9-x86_64.conf
similarity index 100%
rename from gnu/packages/linux-libre-4.9-x86_64.conf
rename to gnu/packages/aux-files/linux-libre/4.9-x86_64.conf
diff --git a/gnu/packages/linux.scm b/gnu/packages/linux.scm
index fcbd932..0fc536e 100644
--- a/gnu/packages/linux.scm
+++ b/gnu/packages/linux.scm
@@ -8,7 +8,7 @@
 ;;; Copyright © 2015, 2016 Efraim Flashner <efraim@flashner.co.il>
 ;;; Copyright © 2016 Christopher Allan Webber <cwebber@dustycloud.org>
 ;;; Copyright © 2016, 2017 Tobias Geerinckx-Rice <me@tobias.gr>
-;;; Copyright © 2016 Alex Kost <alezost@gmail.com>
+;;; Copyright © 2016, 2017 Alex Kost <alezost@gmail.com>
 ;;; Copyright © 2016 Raymond Nicholson <rain1@openmailbox.org>
 ;;; Copyright © 2016 Mathieu Lirzin <mthl@gnu.org>
 ;;; Copyright © 2016 Nicolas Goaziou <mail@nicolasgoaziou.fr>
@@ -194,11 +194,10 @@
 (define* (kernel-config arch #:key variant)
   "Return the absolute file name of the Linux-Libre build configuration file
 for ARCH and optionally VARIANT, or #f if there is no such configuration."
-  (let* ((name (string-append "linux-libre-"
-                              (if variant (string-append variant "-") "")
+  (let* ((name (string-append (if variant (string-append variant "-") "")
                               (if (string=? "i386" arch) "i686" arch) ".conf"))
-         (file (string-append "gnu/packages/" name)))
-    (search-path %load-path file)))
+         (file (string-append "linux-libre/" name)))
+    (search-auxiliary-file file)))
 
 (define %default-extra-linux-options
   `(;; https://lists.gnu.org/archive/html/guix-devel/2014-04/msg00039.html
-- 
2.10.2

^ permalink raw reply related	[flat|nested] 10+ messages in thread

* [PATCH 3/5] gnu: emacs: Move "guix-emacs.el" to "aux-files".
  2017-02-18  9:21 [PATCH 0/5] gnu/packages/aux-files Alex Kost
  2017-02-18  9:21 ` [PATCH 1/5] packages: Add 'search-auxiliary-file' Alex Kost
  2017-02-18  9:21 ` [PATCH 2/5] gnu: linux: Move configuration files to "aux-files" Alex Kost
@ 2017-02-18  9:21 ` Alex Kost
  2017-02-18  9:21 ` [PATCH 4/5] gnu: emacs: Simplify "guix-emacs.el" Alex Kost
                   ` (2 subsequent siblings)
  5 siblings, 0 replies; 10+ messages in thread
From: Alex Kost @ 2017-02-18  9:21 UTC (permalink / raw)
  To: guix-devel

* emacs/guix-emacs.el: Rename to...
* gnu/packages/aux-files/emacs/guix-emacs.el: ... this.
* Makefile.am (AUX_FILES): Add it.
* gnu/packages/emacs.scm (emacs)[inputs]: Remove 'guix' source.
[native-inputs]: Add "guix-emacs.el" auxiliary file.
[arguments]: Adjust 'install-site-start' phase accordingly.
---
 Makefile.am                                          |  1 +
 .../packages/aux-files/emacs}/guix-emacs.el          |  0
 gnu/packages/emacs.scm                               | 20 ++++++++------------
 3 files changed, 9 insertions(+), 12 deletions(-)
 rename {emacs => gnu/packages/aux-files/emacs}/guix-emacs.el (100%)

diff --git a/Makefile.am b/Makefile.am
index 1e26da8..0ee4438 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -198,6 +198,7 @@ dist_noinst_DATA = guix/tests.scm guix/tests/http.scm
 
 # Auxiliary files for packages.
 AUX_FILES =						\
+  gnu/packages/aux-files/emacs/guix-emacs.el		\
   gnu/packages/aux-files/linux-libre/4.9-i686.conf	\
   gnu/packages/aux-files/linux-libre/4.9-x86_64.conf	\
   gnu/packages/aux-files/linux-libre/4.4-i686.conf	\
diff --git a/emacs/guix-emacs.el b/gnu/packages/aux-files/emacs/guix-emacs.el
similarity index 100%
rename from emacs/guix-emacs.el
rename to gnu/packages/aux-files/emacs/guix-emacs.el
diff --git a/gnu/packages/emacs.scm b/gnu/packages/emacs.scm
index 04c7a08..51a579a 100644
--- a/gnu/packages/emacs.scm
+++ b/gnu/packages/emacs.scm
@@ -133,19 +133,15 @@
                (("/bin/pwd")
                 "pwd"))))
          (add-after 'install 'install-site-start
-           ;; Copy guix-emacs.el from Guix and add it to site-start.el.  This
-           ;; way, Emacs packages provided by Guix and installed in
+           ;; Use 'guix-emacs' in "site-start.el".  This way, Emacs packages
+           ;; provided by Guix and installed in
            ;; ~/.guix-profile/share/emacs/site-lisp/guix.d/PACKAGE-VERSION are
            ;; automatically found.
            (lambda* (#:key inputs outputs #:allow-other-keys)
-             (let* ((guix-src (assoc-ref inputs "guix-src"))
-                    (out      (assoc-ref outputs "out"))
-                    (lisp-dir (string-append out "/share/emacs/site-lisp"))
-                    (unpack   (assoc-ref %standard-phases 'unpack)))
-               (mkdir "guix")
-               (with-directory-excursion "guix"
-                 (apply unpack (list #:source guix-src))
-                 (install-file "emacs/guix-emacs.el" lisp-dir))
+             (let* ((out      (assoc-ref outputs "out"))
+                    (lisp-dir (string-append out "/share/emacs/site-lisp")))
+               (copy-file (assoc-ref inputs "guix-emacs.el")
+                          (string-append lisp-dir "/guix-emacs.el"))
                (with-output-to-file (string-append lisp-dir "/site-start.el")
                  (lambda ()
                    (display "(require 'guix-emacs nil t)")))
@@ -175,13 +171,13 @@
        ("libsm" ,libsm)
        ("alsa-lib" ,alsa-lib)
        ("dbus" ,dbus)
-       ("guix-src" ,(package-source guix))
 
        ;; multilingualization support
        ("libotf" ,libotf)
        ("m17n-lib" ,m17n-lib)))
     (native-inputs
-     `(("pkg-config" ,pkg-config)
+     `(("guix-emacs.el" ,(search-auxiliary-file "emacs/guix-emacs.el"))
+       ("pkg-config" ,pkg-config)
        ("texinfo" ,texinfo)))
 
     (native-search-paths
-- 
2.10.2

^ permalink raw reply related	[flat|nested] 10+ messages in thread

* [PATCH 4/5] gnu: emacs: Simplify "guix-emacs.el".
  2017-02-18  9:21 [PATCH 0/5] gnu/packages/aux-files Alex Kost
                   ` (2 preceding siblings ...)
  2017-02-18  9:21 ` [PATCH 3/5] gnu: emacs: Move "guix-emacs.el" " Alex Kost
@ 2017-02-18  9:21 ` Alex Kost
  2017-02-18  9:21 ` [PATCH 5/5] .gitignore: Remove stale entries Alex Kost
  2017-02-27 13:46 ` [PATCH 0/5] gnu/packages/aux-files Alex Kost
  5 siblings, 0 replies; 10+ messages in thread
From: Alex Kost @ 2017-02-18  9:21 UTC (permalink / raw)
  To: guix-devel

* gnu/packages/aux-files/emacs/guix-emacs.el: Do not try to require
'guix-profiles'.  Do not call 'guix-emacs-autoload-packages' in the top
level.
(guix-package-enable-at-startup): Remove.  This variable can't be set by
a user since this file is loaded before user config.
(guix-emacs-autoload-packages): Use 'guix-read-package-profile' instead
of 'guix-profile-prompt' in interactive clause (it was renamed in
Emacs-Guix).
* gnu/packages/emacs.scm (emacs)[arguments]: Call
'guix-emacs-autoload-packages' in "site-start.el" after requiring
'guix-emacs'.
---
 gnu/packages/aux-files/emacs/guix-emacs.el | 21 +++++----------------
 gnu/packages/emacs.scm                     |  4 +++-
 2 files changed, 8 insertions(+), 17 deletions(-)

diff --git a/gnu/packages/aux-files/emacs/guix-emacs.el b/gnu/packages/aux-files/emacs/guix-emacs.el
index 099261a..2bbd639 100644
--- a/gnu/packages/aux-files/emacs/guix-emacs.el
+++ b/gnu/packages/aux-files/emacs/guix-emacs.el
@@ -1,6 +1,6 @@
 ;;; guix-emacs.el --- Emacs packages installed with Guix
 
-;; Copyright © 2014, 2015, 2016 Alex Kost <alezost@gmail.com>
+;; Copyright © 2014, 2015, 2016, 2017 Alex Kost <alezost@gmail.com>
 
 ;; This file is part of GNU Guix.
 
@@ -19,22 +19,14 @@
 
 ;;; Commentary:
 
-;; This file provides auxiliary code for working with Emacs packages
+;; This file provides auxiliary code to autoload Emacs packages
 ;; installed with Guix.
 
 ;;; Code:
 
 (require 'cl-lib)
-(unless (require 'guix-profiles nil t)
-  (defvar guix-user-profile (expand-file-name "~/.guix-profile")))
 
-(defcustom guix-package-enable-at-startup t
-  "If non-nil, activate Emacs packages installed in a user profile.
-Set this variable to nil before requiring `guix-emacs' file to
-avoid loading autoloads of Emacs packages installed in
-`guix-user-profile'."
-  :type 'boolean
-  :group 'guix)
+(defvar guix-user-profile (expand-file-name "~/.guix-profile"))
 
 (defvar guix-emacs-autoloads nil
   "List of the last loaded Emacs autoloads.")
@@ -92,8 +84,8 @@ profiles.
 'Autoload' means add directories with Emacs packages to
 `load-path' and load 'autoloads' files matching
 `guix-emacs-autoloads-regexp'."
-  (interactive (list (if (fboundp 'guix-profile-prompt)
-                         (funcall 'guix-profile-prompt)
+  (interactive (list (if (fboundp 'guix-read-package-profile)
+                         (funcall 'guix-read-package-profile)
                        guix-user-profile)))
   (let ((profiles (or profiles
                       (list "/run/current-system/profile"
@@ -115,9 +107,6 @@ profiles.
             (setq guix-emacs-autoloads
                   (append new-autoloads guix-emacs-autoloads))))))))
 
-(when guix-package-enable-at-startup
-  (guix-emacs-autoload-packages))
-
 (provide 'guix-emacs)
 
 ;;; guix-emacs.el ends here
diff --git a/gnu/packages/emacs.scm b/gnu/packages/emacs.scm
index 51a579a..94ca52a 100644
--- a/gnu/packages/emacs.scm
+++ b/gnu/packages/emacs.scm
@@ -144,7 +144,9 @@
                           (string-append lisp-dir "/guix-emacs.el"))
                (with-output-to-file (string-append lisp-dir "/site-start.el")
                  (lambda ()
-                   (display "(require 'guix-emacs nil t)")))
+                   (display
+                    (string-append "(when (require 'guix-emacs nil t)\n"
+                                   "  (guix-emacs-autoload-packages))\n"))))
                #t))))))
     (inputs
      `(("gnutls" ,gnutls)
-- 
2.10.2

^ permalink raw reply related	[flat|nested] 10+ messages in thread

* [PATCH 5/5] .gitignore: Remove stale entries.
  2017-02-18  9:21 [PATCH 0/5] gnu/packages/aux-files Alex Kost
                   ` (3 preceding siblings ...)
  2017-02-18  9:21 ` [PATCH 4/5] gnu: emacs: Simplify "guix-emacs.el" Alex Kost
@ 2017-02-18  9:21 ` Alex Kost
  2017-02-27 13:46 ` [PATCH 0/5] gnu/packages/aux-files Alex Kost
  5 siblings, 0 replies; 10+ messages in thread
From: Alex Kost @ 2017-02-18  9:21 UTC (permalink / raw)
  To: guix-devel

This is a followup to commit deb6276dda81a69da38e842d269c5370a28fa5cf.

* .gitignore: Remove "/emacs/..." lines.
---
 .gitignore | 5 -----
 1 file changed, 5 deletions(-)

diff --git a/.gitignore b/.gitignore
index 0897c95..1fc22d7 100644
--- a/.gitignore
+++ b/.gitignore
@@ -44,11 +44,6 @@
 /doc/os-config-desktop.texi
 /doc/stamp-vti
 /doc/version.texi
-/emacs/Makefile
-/emacs/Makefile.in
-/emacs/guix-autoloads.el
-/emacs/guix-config.el
-/emacs/guix-helper.scm
 /etc/guix-daemon.conf
 /etc/guix-daemon.service
 /etc/guix-publish.conf
diff --git a/gnu/packages.scm b/gnu/packages.scm
index 0aa289d..10ca3bb 100644
--- a/gnu/packages.scm
+++ b/gnu/packages.scm
@@ -2,7 +2,7 @@
 ;;; Copyright © 2012, 2013, 2014, 2015, 2016, 2017 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2013 Mark H Weaver <mhw@netris.org>
 ;;; Copyright © 2014 Eric Bavier <bavier@member.fsf.org>
-;;; Copyright © 2016 Alex Kost <alezost@gmail.com>
+;;; Copyright © 2016, 2017 Alex Kost <alezost@gmail.com>
 ;;; Copyright © 2016 Mathieu Lirzin <mthl@gnu.org>
 ;;;
 ;;; This file is part of GNU Guix.
@@ -40,8 +40,10 @@
   #:use-module (srfi srfi-39)
   #:export (search-patch
             search-patches
+            search-auxiliary-file
             search-bootstrap-binary
             %patch-path
+            %auxiliary-files-path
             %bootstrap-binaries-path
             %package-module-path
 
@@ -62,17 +64,27 @@
 ;;;
 ;;; Code:
 
 ;; By default, we store patches and bootstrap binaries alongside Guile
 ;; modules.  This is so that these extra files can be found without
 ;; requiring a special setup, such as a specific installation directory
 ;; and an extra environment variable.  One advantage of this setup is
 ;; that everything just works in an auto-compilation setting.
 
 (define %bootstrap-binaries-path
   (make-parameter
    (map (cut string-append <> "/gnu/packages/bootstrap")
         %load-path)))
 
+(define %auxiliary-files-path
+  (make-parameter
+   (map (cut string-append <> "/gnu/packages/aux-files")
+        %load-path)))
+
+(define (search-auxiliary-file file-name)
+  "Search the auxiliary FILE-NAME.  Return #f if not found."
+  (search-path (%auxiliary-files-path) file-name))
+
 (define (search-patch file-name)
   "Search the patch FILE-NAME.  Raise an error if not found."
   (or (search-path (%patch-path) file-name)
@@ -62,17 +64,27 @@
 ;;; Code:
 
-;; By default, we store patches and bootstrap binaries alongside Guile
-;; modules.  This is so that these extra files can be found without
-;; requiring a special setup, such as a specific installation directory
-;; and an extra environment variable.  One advantage of this setup is
-;; that everything just works in an auto-compilation setting.
+;; By default, we store patches, auxiliary files and bootstrap binaries
+;; alongside Guile modules.  This is so that these extra files can be
+;; found without requiring a special setup, such as a specific
+;; installation directory and an extra environment variable.  One
+;; advantage of this setup is that everything just works in an
+;; auto-compilation setting.
 
 (define %bootstrap-binaries-path
-- 
2.10.2

^ permalink raw reply related	[flat|nested] 10+ messages in thread

* Re: [PATCH 0/5] gnu/packages/aux-files
  2017-02-18  9:21 [PATCH 0/5] gnu/packages/aux-files Alex Kost
                   ` (4 preceding siblings ...)
  2017-02-18  9:21 ` [PATCH 5/5] .gitignore: Remove stale entries Alex Kost
@ 2017-02-27 13:46 ` Alex Kost
  2017-02-27 15:07   ` Ricardo Wurmus
  2017-03-06 15:50   ` Ludovic Courtès
  5 siblings, 2 replies; 10+ messages in thread
From: Alex Kost @ 2017-02-27 13:46 UTC (permalink / raw)
  To: guix-devel

Alex Kost (2017-02-18 12:21 +0300) wrote:

> Hello, as discussed at
>
>   http://lists.gnu.org/archive/html/guix-devel/2016-12/msg01174.html
>
> this patchset moves linux-libre .conf files and "guix-emacs.el" (needed
> for Emacs) to "gnu/packages/aux-files", also it modifies "guix-emacs.el"
> a bit.  These patches shouldn't change anything in a user experience.
>
> The .conf files will be called like this:
>
>   gnu/packages/aux-files/linux-libre/4.9-i686.conf
>
> or is it better to name them like this:
>
>   gnu/packages/aux-files/linux-libre/linux-libre-4.9-i686.conf   or
>   gnu/packages/aux-files/linux-libre-4.9-i686.conf
>
> or something else?
>
> IIUC Ludovic is AFK now, so I would like to push these patches in a week
> or so, if there will be no comments.

Since there were no comments, I applied this patchset to master.

-- 
Alex

^ permalink raw reply	[flat|nested] 10+ messages in thread

* Re: [PATCH 0/5] gnu/packages/aux-files
  2017-02-27 13:46 ` [PATCH 0/5] gnu/packages/aux-files Alex Kost
@ 2017-02-27 15:07   ` Ricardo Wurmus
  2017-02-28 14:01     ` Alex Kost
  2017-03-06 15:50   ` Ludovic Courtès
  1 sibling, 1 reply; 10+ messages in thread
From: Ricardo Wurmus @ 2017-02-27 15:07 UTC (permalink / raw)
  To: Alex Kost; +Cc: guix-devel


Alex Kost <alezost@gmail.com> writes:

>> IIUC Ludovic is AFK now, so I would like to push these patches in a week
>> or so, if there will be no comments.
>
> Since there were no comments, I applied this patchset to master.

I missed this patch set the first time around and only just went over
it.  It looks good to me.  Thanks!

--
Ricardo

GPG: BCA6 89B6 3655 3801 C3C6  2150 197A 5888 235F ACAC
https://elephly.net

^ permalink raw reply	[flat|nested] 10+ messages in thread

* Re: [PATCH 0/5] gnu/packages/aux-files
  2017-02-27 15:07   ` Ricardo Wurmus
@ 2017-02-28 14:01     ` Alex Kost
  0 siblings, 0 replies; 10+ messages in thread
From: Alex Kost @ 2017-02-28 14:01 UTC (permalink / raw)
  To: Ricardo Wurmus; +Cc: guix-devel

Ricardo Wurmus (2017-02-27 16:07 +0100) wrote:

> Alex Kost <alezost@gmail.com> writes:
>
>>> IIUC Ludovic is AFK now, so I would like to push these patches in a week
>>> or so, if there will be no comments.
>>
>> Since there were no comments, I applied this patchset to master.
>
> I missed this patch set the first time around and only just went over
> it.  It looks good to me.  Thanks!

Thanks, I decided that I would just go on with it in a hope it wouldn't
break things :-)

-- 
Alex

^ permalink raw reply	[flat|nested] 10+ messages in thread

* Re: [PATCH 0/5] gnu/packages/aux-files
  2017-02-27 13:46 ` [PATCH 0/5] gnu/packages/aux-files Alex Kost
  2017-02-27 15:07   ` Ricardo Wurmus
@ 2017-03-06 15:50   ` Ludovic Courtès
  1 sibling, 0 replies; 10+ messages in thread
From: Ludovic Courtès @ 2017-03-06 15:50 UTC (permalink / raw)
  To: Alex Kost; +Cc: guix-devel

Alex Kost <alezost@gmail.com> skribis:

> Alex Kost (2017-02-18 12:21 +0300) wrote:
>
>> Hello, as discussed at
>>
>>   http://lists.gnu.org/archive/html/guix-devel/2016-12/msg01174.html
>>
>> this patchset moves linux-libre .conf files and "guix-emacs.el" (needed
>> for Emacs) to "gnu/packages/aux-files", also it modifies "guix-emacs.el"
>> a bit.  These patches shouldn't change anything in a user experience.
>>
>> The .conf files will be called like this:
>>
>>   gnu/packages/aux-files/linux-libre/4.9-i686.conf
>>
>> or is it better to name them like this:
>>
>>   gnu/packages/aux-files/linux-libre/linux-libre-4.9-i686.conf   or
>>   gnu/packages/aux-files/linux-libre-4.9-i686.conf
>>
>> or something else?
>>
>> IIUC Ludovic is AFK now, so I would like to push these patches in a week
>> or so, if there will be no comments.
>
> Since there were no comments, I applied this patchset to master.

Great, thanks for working on it!  It looks right to me.

Ludo’.

^ permalink raw reply	[flat|nested] 10+ messages in thread

end of thread, other threads:[~2017-03-06 15:50 UTC | newest]

Thread overview: 10+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2017-02-18  9:21 [PATCH 0/5] gnu/packages/aux-files Alex Kost
2017-02-18  9:21 ` [PATCH 1/5] packages: Add 'search-auxiliary-file' Alex Kost
2017-02-18  9:21 ` [PATCH 2/5] gnu: linux: Move configuration files to "aux-files" Alex Kost
2017-02-18  9:21 ` [PATCH 3/5] gnu: emacs: Move "guix-emacs.el" " Alex Kost
2017-02-18  9:21 ` [PATCH 4/5] gnu: emacs: Simplify "guix-emacs.el" Alex Kost
2017-02-18  9:21 ` [PATCH 5/5] .gitignore: Remove stale entries Alex Kost
2017-02-27 13:46 ` [PATCH 0/5] gnu/packages/aux-files Alex Kost
2017-02-27 15:07   ` Ricardo Wurmus
2017-02-28 14:01     ` Alex Kost
2017-03-06 15:50   ` Ludovic Courtès

Code repositories for project(s) associated with this external index

	https://git.savannah.gnu.org/cgit/guix.git

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.